package com.fs.fastGpt.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.fastGpt.domain.FastGptChatReplaceText;

import java.util.List;

/**
 * 易错词语Service接口
 * 
 * @author fs
 * @date 2025-01-18
 */
public interface IFastGptChatReplaceTextService extends IService<FastGptChatReplaceText>{
    /**
     * 查询易错词语
     * 
     * @param id 易错词语主键
     * @return 易错词语
     */
    FastGptChatReplaceText selectFastGptChatReplaceTextById(Long id);

    /**
     * 查询易错词语列表
     * 
     * @param fastGptChatReplaceText 易错词语
     * @return 易错词语集合
     */
    List<FastGptChatReplaceText> selectFastGptChatReplaceTextList(FastGptChatReplaceText fastGptChatReplaceText);

    /**
     * 新增易错词语
     * 
     * @param fastGptChatReplaceText 易错词语
     * @return 结果
     */
    int insertFastGptChatReplaceText(FastGptChatReplaceText fastGptChatReplaceText);

    /**
     * 修改易错词语
     * 
     * @param fastGptChatReplaceText 易错词语
     * @return 结果
     */
    int updateFastGptChatReplaceText(FastGptChatReplaceText fastGptChatReplaceText);

    /**
     * 批量删除易错词语
     * 
     * @param ids 需要删除的易错词语主键集合
     * @return 结果
     */
    int deleteFastGptChatReplaceTextByIds(Long[] ids);

    /**
     * 删除易错词语信息
     * 
     * @param id 易错词语主键
     * @return 结果
     */
    int deleteFastGptChatReplaceTextById(Long id);
}
